# 文字绘制程序

### 说明

+ 只支持 ttf 字体
+ 字体不存在会使用 font_list.json 中的第一个字体绘制
+ 确保 font_list.json 中的字体路径有效, 推荐使用绝对路径.   
    因为引擎调用时会导致当前目录更改,从而导致 font_list.json 中的路径失效
    
+ 设计师使用 font_list.json 中的字体名设置文字图层的字体, 严格保证一致, 才会正常绘制    

### 依赖

+ 文字绘制工具依赖 imagemagick 
+ 执行 textpainter_env_install 中的 install_environment.sh 依次安装
   pkg-config
   zlib
   libpng
   libfreetype
   imagemagick
   
+ 最后执行了 ldconfig /usr/local/lib 更新动态库   

### 使用步骤

+ 进入 textpainter_env_install 目录, 使用 root 权限执行  ./install_environment.sh 完成环境安装
+ 执行　convert -version 检查安装结果

    如果打印出下面的结果说明安装成功，　注意最后一行最少要出现　png freetype zlib, 
    否则请查看　install_environment.sh 的步骤重新安装缺少的库
    
    ```text
    slayer@slayer-B250M-D3H:~$ convert -version
    Version: ImageMagick 7.0.8-45 Q16 x86_64 2019-05-16 https://imagemagick.org
    Copyright: © 1999-2019 ImageMagick Studio LLC
    License: https://imagemagick.org/script/license.php
    Features: Cipher DPC HDRI OpenMP(4.0) 
    Delegates (built-in): fontconfig freetype png x zlib
    ```

### 目录结构

该目录结构不能改变

```text
|-- TextPainter  绘制程序, 请保证有执行权限, 命令: chmod +x TextPainter
|-- fonts/       字体目录
|-- font_list.json  字体配置文件, 每新增一个字体需要在 font_list.json 增加
```

# 使用文档
## 字体支持
目前只支持ttf格式字体

## 字体配置
程序运行需要一个字体配置信息json文档。  
该文档中要配置好字体名和改字体文件路径信息。
该文档应该命名为"font_list.json"，并放在该可执行程序同级目录下。  
font_list.json内容格式为： 
```json
{
  "FZSTK":"/home/helloj/Desktop/fonts/FZSTK.TTF",
  "字体名称":"字体文件绝对路径"
}
```

## 测试命令

```text

./TextPainter./font_list.json ./test.json 

```

## 运行方式
1. 从命令行运行该程序，并传入要渲染的文字内容信息配置文件路径。比如  

```
    ./TextPainter ./font_list.json ./test.json
```
    会在当前目录生成 1.png, 2.png

2. 文字内容信息配置文件内存储所有要绘制的文字内容和样式信息，格式参考： 


配置信息来自模板 config.json->assets 里面的文字配置信息

 ```json
[{
	"key": "assetkey0",
	"ui_key": "",
	"ui_extra": "",
	"name": "asset1.png",
	"type": 1,
	"num": 0,
	"size": [544, 960],
	"output":"/home/helloj/Desktop/1.png",
	"ui": {
		"f": "ui0.png",
		"group": 1,
		"index": 0,
		"duration": 99,
		"type": 2,
		"default": "胡歌",　// 文字内容
		"max": 5,
		"font": "SourceHanSans", // 模板中的字体要和 font_list.json 中的key 保持一致
		"size": 36,
		"line_height": 43,
		"fill": "#53453b",
		"stroke": "#000000",
		"width": 0,
		"align": 0,
		"direction": 0,
		"shadow": "#000000",
		"s_alpha": 0.0,
		"s_angle": 0,
		"s_dist": 0,
		"s_size": 0,
		"area": [271, 646, 180, 36]
	}
}, {
	"key": "assetkey2",
	"ui_key": "",
	"ui_extra": "",
	"name": "asset3.png",
	"type": 1,
	"num": 0,
	"size": [544, 960],
	"output":"/home/helloj/Desktop/2.png",
	"ui": {
		"group": 1,
		"index": 1,
		"duration": 94,
		"type": 2,
		"default": "男",
		"max": 2,
		"font": "SourceHanSans",
		"size": 36,
		"line_height": 43,
		"fill": "#53453b",
		"stroke": "#000000",
		"width": 0,
		"align": 0,
		"direction": 0,
		"shadow": "#000000",
		"s_alpha": 0.0,
		"s_angle": 0,
		"s_dist": 0,
		"s_size": 0,
		"area": [271, 707, 72, 34]
	}
}]
```

3. 返回值
   程序正常退出返回0
   如果参数错误、配置文件不存在、配置文件格式错误等返回-1

## 文字样式绘制支持的属性列表

1. size
   输出图片宽高
2. output
   输出文件路径，必须为png文件
3. font
   字体名称，该名称对应到font_list.json里配置的字体文件。  
   如果一个文字名称在font_list.json找不到对应的字体文件，那么会使用font_list.json里配置的第一个字体来绘制
4. size
   字体大小
5. line_height
   行高
6. fill
   填充文字颜色
7. align
   对齐方式

8. stroke 
    描边颜色
9. width
	描边大小


